Module request

Module request 

Request extras — re-exports and helpers around Axum extractors.

Structs

App
An extractor that yields the container reference, with ?-friendly error.
Bytes
A cheaply cloneable and sliceable chunk of contiguous memory.
Form
URL encoded extractor and response.
HeaderMap
A specialized multimap for header names and values.
Json
JSON Extractor / Response.
Method
The Request Method (VERB)
Path
Extractor that will get captures from the URL and parse them using serde.
Query
Extractor that deserializes query strings into some type.
State
Extractor for state.
StatusCode
An HTTP status code (status-code in RFC 9110 et al.).
Uri
The URI component of a request.